@@ -151,12 +151,11 @@ macro_rules! impl_vector {
             fn name(&self) -> &'static str { return Self::NAME; }
 
             #[inline]
-            fn to_array(self) -> [T; $len] {
+            fn as_array(self) -> [T; $len] {
                 return [ $(self.$field), + ];
             }
 
-            #[inline]
-            fn to_vec(self) -> std::vec::Vec<T> {
+            fn as_vec(self) -> std::vec::Vec<T> {
                 let mut vec = std::vec::Vec::with_capacity(Self::LEN);
                 $( vec.push(self.$field); ) +
                 return vec;
@@ -610,7 +609,7 @@ impl<T> TuplableVector<T, { Vector2::<()>::LEN }> for Vector2<T> {
     type Output = (T, T);
 
     #[inline]
-    fn to_tuple(self) -> Self::Output {
+    fn as_tuple(self) -> Self::Output {
         return (self.x, self.y);
     }
 }
@@ -629,7 +628,7 @@ impl<T> TuplableVector<T, { Vector3::<()>::LEN }> for Vector3<T> {
     type Output = (T, T, T);
 
     #[inline]
-    fn to_tuple(self) -> Self::Output {
+    fn as_tuple(self) -> Self::Output {
         return (self.x, self.y, self.z);
     }
 }
@@ -648,7 +647,7 @@ impl<T> TuplableVector<T, { Vector4::<()>::LEN }> for Vector4<T> {
     type Output = (T, T, T, T);
 
     #[inline]
-    fn to_tuple(self) -> Self::Output {
+    fn as_tuple(self) -> Self::Output {
         return (self.x, self.y, self.z, self.w);
     }
 }
